﻿using System;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Drawing;
using System.Globalization;
using PdfSharp;
using PdfSharp.Pdf;
using ThinkGeo.MapSuite.Core;
namespace PdfExtensionWebSample
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapUnit = GeographyUnit.DecimalDegree;
                Map1.CurrentExtent = new RectangleShape(-37.08984375,79.453125,68.37890625,9.140625);

                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

                EcwRasterLayer worldImageLayer = new EcwRasterLayer(MapPath("~/SampleData/world.ecw"));


                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/Countries02.shp"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.StartCap = DrawingLineCap.Round;
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.EndCap = DrawingLineCap.Round;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


                ShapeFileFeatureLayer usStatesLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/USStates.shp"));
                usStatesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.State2;
                usStatesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.StartCap = DrawingLineCap.Round;
                usStatesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                ShapeFileFeatureLayer worldCapitalsLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/WorldCapitals.shp"));
                worldCapitalsLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital3;
                worldCapitalsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                ShapeFileFeatureLayer worldCapitalsLabelsLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/WorldCapitals.shp"));
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Capital3("city_name");
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen = new GeoPen(GeoColor.StandardColors.White, 2);
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen.StartCap = DrawingLineCap.Round;
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen.EndCap = DrawingLineCap.Round;
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SuppressPartialLabels = true;
                worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                worldCapitalsLabelsLayer.DrawingMarginPercentage = 100;

                MrSidRasterLayer sidImageLayer = new MrSidRasterLayer(MapPath("~/SampleData/world.sid"));
                sidImageLayer.UpperThreshold = double.MaxValue;
                sidImageLayer.LowerThreshold = 0;

                Map1.StaticOverlay.Layers.Add(sidImageLayer);
                Map1.StaticOverlay.Layers.Add(worldLayer);
                Map1.StaticOverlay.Layers.Add(usStatesLayer);
                Map1.StaticOverlay.Layers.Add(worldCapitalsLayer);
                Map1.StaticOverlay.Layers.Add(worldCapitalsLabelsLayer);
            }
        }

        protected void Button1_Click(object sender, EventArgs e)
        {
            PdfDocument document = new PdfDocument();
            PdfPage page = document.AddPage();
            // you can set whatthe size of the page manually
            //page.Width = 1200;
            //page.Height = 800;
            page.Size = PageSize.A1;

            PdfGeoCanvas pdfGeoCanvas = new PdfGeoCanvas();

            //ratio of height and width of DrawingArea should be the same as the ratio of heigth and width of the Map1 control.
            pdfGeoCanvas.DrawingArea = new Rectangle(0, 0, 600, 400);

            //Here is the extent for the output to pdf.
            RectangleShape extent = null;
            if (rblExtent.SelectedItem.ToString().Equals("WorldExtent"))
            {
                extent = new RectangleShape(-140, 60, 140, -60);
            }
            else
            {
                extent = Map1.CurrentExtent;
            }

            Collection<SimpleCandidate> labelsInLayers = new Collection<SimpleCandidate>();
            foreach (Layer layer in Map1.StaticOverlay.Layers)
            {
                pdfGeoCanvas.BeginDrawing(page, extent, GeographyUnit.DecimalDegree);
                layer.Open();
                layer.Draw(pdfGeoCanvas, labelsInLayers);
                layer.Close();
                pdfGeoCanvas.EndDrawing();
            }

            string filename = MapPath("~/MapSuite PDF Map.pdf");
            document.Save(filename);
            Process.Start(filename);
        }
    }
}
